Index: trunk/src/org/openstreetmap/josm/data/osm/BBox.java
===================================================================
--- trunk/src/org/openstreetmap/josm/data/osm/BBox.java	(revision 9975)
+++ trunk/src/org/openstreetmap/josm/data/osm/BBox.java	(revision 9976)
@@ -153,10 +153,6 @@
      */
     public boolean bounds(BBox b) {
-        if (!(xmin <= b.xmin) ||
-                !(xmax >= b.xmax) ||
-                !(ymin <= b.ymin) ||
-                !(ymax >= b.ymax))
-            return false;
-        return true;
+        return xmin <= b.xmin && xmax >= b.xmax
+            && ymin <= b.ymin && ymax >= b.ymax;
     }
 
@@ -167,10 +163,6 @@
      */
     public boolean bounds(LatLon c) {
-        if ((xmin <= c.lon()) &&
-                (xmax >= c.lon()) &&
-                (ymin <= c.lat()) &&
-                (ymax >= c.lat()))
-            return true;
-        return false;
+        return xmin <= c.lon() && xmax >= c.lon()
+            && ymin <= c.lat() && ymax >= c.lat();
     }
 
Index: trunk/src/org/openstreetmap/josm/gui/preferences/imagery/CacheContentsPanel.java
===================================================================
--- trunk/src/org/openstreetmap/josm/gui/preferences/imagery/CacheContentsPanel.java	(revision 9975)
+++ trunk/src/org/openstreetmap/josm/gui/preferences/imagery/CacheContentsPanel.java	(revision 9976)
@@ -243,5 +243,5 @@
 
     private static DefaultTableModel getTableModel(final CacheAccess<String, BufferedImageCacheEntry> cache) {
-        final DefaultTableModel tableModel = new DefaultTableModel(
+        return new DefaultTableModel(
                 getCacheStats(cache),
                 new String[]{tr("Cache name"), tr("Object Count"), tr("Clear")}) {
@@ -251,5 +251,4 @@
             }
         };
-        return tableModel;
     }
 }

Index: trunk/src/org/openstreetmap/josm/gui/NavigatableComponent.java
===================================================================
--- trunk/src/org/openstreetmap/josm/gui/NavigatableComponent.java	(revision 9975)
+++ trunk/src/org/openstreetmap/josm/gui/NavigatableComponent.java	(revision 9976)
@@ -1323,12 +1323,12 @@
      * @param osm node to check
      * @param p point clicked
      * @param use_selected whether to prefer selected nodes
      * @return true, if the node fulfills the properties of the function body
      */
-    private boolean isPrecedenceNode(Node osm, Point p, boolean use_selected) {
+    private boolean isPrecedenceNode(Node osm, Point p, boolean useSelected) {
         if (osm != null) {
-            if (!(p.distanceSq(getPoint2D(osm)) > (4)*(4))) return true;
+            if (p.distanceSq(getPoint2D(osm)) <= (4*4)) return true;
             if (osm.isTagged()) return true;
-            if (use_selected && osm.isSelected()) return true;
+            if (useSelected && osm.isSelected()) return true;
         }
         return false;
@@ -1323,12 +1323,12 @@
      * @param osm node to check
      * @param p point clicked
-     * @param use_selected whether to prefer selected nodes
+     * @param useSelected whether to prefer selected nodes
      * @return true, if the node fulfills the properties of the function body
      */